package com.bonus.canteen.core.health.mapper;

import java.util.List;
import com.bonus.canteen.core.health.domain.HealthPopularArticle;

/**
 * 营养科普Mapper接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface HealthPopularArticleMapper {
    /**
     * 查询营养科普
     * 
     * @param articleId 营养科普主键
     * @return 营养科普
     */
    public HealthPopularArticle selectHealthPopularArticleByArticleId(Long articleId);

    /**
     * 查询营养科普列表
     * 
     * @param healthPopularArticle 营养科普
     * @return 营养科普集合
     */
    public List<HealthPopularArticle> selectHealthPopularArticleList(HealthPopularArticle healthPopularArticle);
 
    /**
     * 新增营养科普
     * 
     * @param healthPopularArticle 营养科普
     * @return 结果
     */
    public int insertHealthPopularArticle(HealthPopularArticle healthPopularArticle);

    /**
     * 修改营养科普
     * 
     * @param healthPopularArticle 营养科普
     * @return 结果
     */
    public int updateHealthPopularArticle(HealthPopularArticle healthPopularArticle);

    /**
     * 删除营养科普
     * 
     * @param articleId 营养科普主键
     * @return 结果
     */
    public int deleteHealthPopularArticleByArticleId(Long articleId);

    /**
     * 批量删除营养科普
     * 
     * @param articleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHealthPopularArticleByArticleIds(Long[] articleIds);
}
