package com.bonus.canteen.core.health.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.health.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.health.domain.HealthPopularArticle;
import com.bonus.canteen.core.health.service.IHealthPopularArticleService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 营养科普Controller
 *
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "营养科普接口")
@RestController
@RequestMapping("/health_popular_article")
public class HealthPopularArticleController extends BaseController {
    @Autowired
    private IHealthPopularArticleService healthPopularArticleService;

    /**
     * 查询营养科普列表
     */
    @ApiOperation(value = "查询营养科普列表")
    //@RequiresPermissions("health:article:list")
    @GetMapping("/list")
    public TableDataInfo list(HealthPopularArticle healthPopularArticle) {
        startPage();
        List<HealthPopularArticle> list = healthPopularArticleService.selectHealthPopularArticleList(healthPopularArticle);
        return getDataTable(list);
    }

    /**
     * 导出营养科普列表
     */
    @ApiOperation(value = "导出营养科普列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:article:export")
    @SysLog(title = "营养科普", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出营养科普")
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthPopularArticle healthPopularArticle) {
        List<HealthPopularArticle> list = healthPopularArticleService.selectHealthPopularArticleList(healthPopularArticle);
        ExcelUtil<HealthPopularArticle> util = new ExcelUtil<HealthPopularArticle>(HealthPopularArticle.class);
        util.exportExcel(response, list, "营养科普数据");
    }

    /**
     * 获取营养科普详细信息
     */
    @ApiOperation(value = "获取营养科普详细信息")
    //@RequiresPermissions("health:article:query")
    @GetMapping(value = "/{articleId}")
    public AjaxResult getInfo(@PathVariable("articleId") Long articleId) {
        return success(healthPopularArticleService.selectHealthPopularArticleByArticleId(articleId));
    }

    /**
     * 新增营养科普
     */
    @ApiOperation(value = "新增营养科普")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:article:add")
    @SysLog(title = "营养科普", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增营养科普")
    @PostMapping
    public AjaxResult add(@RequestBody HealthPopularArticle healthPopularArticle) {
        try {
            return toAjax(healthPopularArticleService.insertHealthPopularArticle(healthPopularArticle));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改营养科普
     */
    @ApiOperation(value = "修改营养科普")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:article:edit")
    @SysLog(title = "营养科普", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改营养科普")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody HealthPopularArticle healthPopularArticle) {
        try {
            return toAjax(healthPopularArticleService.updateHealthPopularArticle(healthPopularArticle));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除营养科普
     */
    @ApiOperation(value = "删除营养科普")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:article:remove")
    @SysLog(title = "营养科普", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除营养科普")
	@PostMapping("/del/{articleIds}")
    public AjaxResult remove(@PathVariable Long[] articleIds) {
        return toAjax(healthPopularArticleService.deleteHealthPopularArticleByArticleIds(articleIds));
    }
}
